﻿--[[
ClosetGnome, a World of Warcraft addon to manage item sets.
Copyright (C) 2007 Rabbit.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
]]

if GetEquipmentSetInfo then return end

local ClosetGnome = ClosetGnome
assert(ClosetGnome, "ClosetGnome-UI-LDB requires ClosetGnome to run.")

if not LibStub then return end
local ldb = LibStub:GetLibrary("LibDataBroker-1.1", true)
if not ldb then return end

local al = LibStub("AceLocale-3.0")

-----------------------------------------------------------------------
-- Localization
do
	do
		local L = al:NewLocale("ClosetGnome-UI-LDB", "enUS", true)
		L["Use the menu (|cffeda55fRight-Click|r) to equip, edit or delete item sets. |cffeda55fClick|r to create a new set."] = true
		L["|cffeda55fClick|r to equip, |cffeda55fShift-Click|r to edit and |cffeda55fCtrl-Click|r to delete %s."] = true
		L["no_menu"] = "You haven't created any ClosetGnome sets, so there's no menu for you here. Look in the interface options and try to click the display to create a set."
	end
	do
		local L = al:NewLocale("ClosetGnome-UI-LDB", "frFR")
		if L then
			L["Use the menu (|cffeda55fRight-Click|r) to equip, edit or delete item sets. |cffeda55fClick|r to create a new set."] = "Utilisez le menu (|cffeda55fclic droit|r) pour équiper, éditer ou supprimer des ensembles. |cffeda55fClic gauche|r pour créer un nouvel ensemble."
			L["|cffeda55fClick|r to equip, |cffeda55fShift-Click|r to edit and |cffeda55fCtrl-Click|r to delete %s."] = "|cffeda55fClic gauche|r pour équiper, |cffeda55fShift-clic gauche|r pour éditer et |cffeda55fCtrl-clic gauche|r pour supprimer %s."
	end
	do
		local L = al:NewLocale("ClosetGnome-UI-LDB", "deDE")
		if L then
		L["Use the menu (|cffeda55fRight-Click|r) to equip, edit or delete item sets. |cffeda55fClick|r to create a new set."] = "Benutze das Menü (|cffeda55fRechts-Klick|r) zum Anziehen, Editieren oder zum Löschen eines Sets. |cffeda55fLinks-Klick|r um ein neues Set zu erstellen."
		L["|cffeda55fClick|r to equip, |cffeda55fShift-Click|r to edit and |cffeda55fCtrl-Click|r to delete %s."] = "|cffeda55fKlicken|r zum Anziehen, |cffeda55fShift-Klicken|r zum Editieren und |cffeda55fStrg-Klicken|r zum Löschen von %s."
		L["no_menu"] = "Du hast bisher kein ClosedGnome Set erschaffen, daher ist hier kein Menü für dich. Schau in die Interface Optionen für weitere Optionen oder Links-Klick auf die ClosedGnome Minimaptaste um ein Set zu erstellen."
	end
	do
		local L = al:NewLocale("ClosetGnome-UI-LDB", "koKR")
		if L then
		L["Use the menu (|cffeda55fRight-Click|r) to equip, edit or delete item sets. |cffeda55fClick|r to create a new set."] = "메뉴에서 (|cffeda55f좌-클릭|r) - 아이템 셋트를 착용, 수정 또는 삭제. |cffeda55f클릭|r 새로운 셋트 추가."
		L["|cffeda55fClick|r to equip, |cffeda55fShift-Click|r to edit and |cffeda55fCtrl-Click|r to delete %s."] = "|cffeda55f클릭|r - 착용, |cffeda55fShift-클릭|r - 수정, |cffeda55fCtrl-클릭|r - %s 삭제."
		end
	end
		end
	end
end

local L = al:GetLocale("ClosetGnome-UI-LDB")

-----------------------------------------------------------------------
-- FuBar UI for ClosetGnome

local defaultIcon = "Interface\\Icons\\INV_Chest_Cloth_17"

CGLDB = ldb:NewDataObject("ClosetGnome", {
	type = "data source",
	text = "ClosetGnome",
	icon = defaultIcon,
})

local callbacks = LibStub("CallbackHandler-1.0"):New(CGLDB)

local icon = LibStub("LibDBIcon-1.0", true)
local menu = {}
local menuNeedsUpdate = true

local CGLDB = CGLDB
local lastEquippedSet = nil

local function menuSorter(a, b)
	return a.text > b.text
end

local function updateMenu()
	menuNeedsUpdate = nil
	menu = wipe(menu)
	for k in pairs(ClosetGnome.db.char.set) do
		if not ClosetGnome:HideSetFromUI(k) then
			local name = ClosetGnome:GetSetDisplayName(k)
			if ClosetGnome.db.char.keybindings[k] then
				name = name .. " |cff999999(" .. ClosetGnome.db.char.keybindings[k] .. ")|r"
			end
			local x = {
				text = name,
				tooltipTitle = k,
				tooltipText = L["|cffeda55fClick|r to equip, |cffeda55fShift-Click|r to edit and |cffeda55fCtrl-Click|r to delete %s."]:format(k),
				func = function()
					if IsShiftKeyDown() then
						ClosetGnome:CreateOrUpdateSet(k)
					elseif IsControlKeyDown() then
						ClosetGnome:DeleteSet(k)
					else
						ClosetGnome:WearSet(k)
					end
				end,
				icon = ClosetGnome.db.char.icons[k],
			}
			table.insert(menu, x)
		end
	end
	table.sort(menu, menuSorter)
	local num = #menu
	callbacks:Fire("OnMenu", menu)
	if #menu > num then
		table.insert(menu, num+1, { text = "" })
	end
end

local popupFrame = CreateFrame("Frame", "ClosetGnomeMenu", UIParent, "UIDropDownMenuTemplate")
function CGLDB.OnClick(self, button)
	if button == "RightButton" then
		if menuNeedsUpdate then updateMenu() end
		if #menu == 0 then
			print(L["no_menu"])
		else
			EasyMenu(menu, popupFrame, self, 20, 4, "MENU")
		end
	else
		if IsShiftKeyDown() then
			ClosetGnome:CreateOrUpdateSet(lastEquippedSet)
		else
			ClosetGnome:CreateOrUpdateSet()
		end
	end
end

function CGLDB.OnTooltipShow(tt)
	tt:AddLine("ClosetGnome")
	tt:AddLine(L["Use the menu (|cffeda55fRight-Click|r) to equip, edit or delete item sets. |cffeda55fClick|r to create a new set."], 0.2, 1, 0.2, 1)
end

local function updateDisplay()
	CGLDB.text = lastEquippedSet and ClosetGnome:GetSetDisplayName(lastEquippedSet) or "ClosetGnome"
	CGLDB.icon = ClosetGnome.db.char.icons[lastEquippedSet] or defaultIcon
end

local function updateLatest(event, set)
	lastEquippedSet = set
	updateDisplay()
	menuNeedsUpdate = true
end
local function removeLatest(event, set)
	menuNeedsUpdate = true
	if lastEquippedSet == set then
		lastEquippedSet = nil
		updateDisplay()
	end
end
local function init()
	for k in pairs(ClosetGnome.db.char.set) do
		if ClosetGnome:IsSetFullyEquipped(k) then
			updateLatest(nil, k)
			break
		end
	end
	if icon then
		icon:Register("ClosetGnome", CGLDB, ClosetGnome.db.profile.minimap)
	end
end

ClosetGnome.RegisterCallback(CGLDB, "UpdateSet", updateLatest)
ClosetGnome.RegisterCallback(CGLDB, "AddSet", updateLatest)
ClosetGnome.RegisterCallback(CGLDB, "WearSet", updateLatest)
ClosetGnome.RegisterCallback(CGLDB, "DeleteSet", removeLatest)
ClosetGnome.RegisterCallback(CGLDB, "Initialized", init)

